:html_theme.sidebar_secondary.remove:

# Beamline Experiment Control (BEC)

A python-based control system for experiments at large-scale facilities.

<br><br>

````{grid} 2
:gutter: 5

```{grid-item-card}
:link: introduction
:link-type: ref
:img-top: /assets/index_getting_started.svg
:text-align: center

## Introduction

General information about BEC.
```

```{grid-item-card}
:link: user
:link-type: ref
:img-top:  /assets/index_user_guide.svg
:text-align: center

## User guide

Information for users of BEC.
```

```{grid-item-card} 
:link: developer
:link-type: ref
:img-top: /assets/index_contribute.svg
:text-align: center

## Developer guide

Information for developers of BEC. 
```

```{grid-item-card} 
:link: api_reference
:link-type: ref
:img-top: /assets/index_api.svg
:text-align: center

## API reference

Comprehensive reference of all BEC classes, functions, and methods.
```

````


```{toctree}
---
numbered: true
maxdepth: 2
hidden: true
---

introduction/introduction
user/user
developer/developer
api_reference/api_reference
```





